Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewEpochStartInterceptorsContainer ¶
func NewEpochStartInterceptorsContainer(args ArgsEpochStartInterceptorContainer) (process.InterceptorsContainer, error)
NewEpochStartInterceptorsContainer will return a real interceptors container factory, but with many disabled components
Types ¶
type ArgsEpochStartInterceptorContainer ¶
type ArgsEpochStartInterceptorContainer struct {
Config config.Config
ShardCoordinator sharding.Coordinator
TxSignMarshalizer marshal.Marshalizer
ProtoMarshalizer marshal.Marshalizer
Hasher hashing.Hasher
Messenger process.TopicHandler
DataPool dataRetriever.PoolsHolder
SingleSigner crypto.SingleSigner
BlockSingleSigner crypto.SingleSigner
KeyGen crypto.KeyGenerator
BlockKeyGen crypto.KeyGenerator
WhiteListHandler update.WhiteListHandler
WhiteListerVerifiedTxs update.WhiteListHandler
AddressPubkeyConv core.PubkeyConverter
NonceConverter typeConverters.Uint64ByteSliceConverter
ChainID []byte
ArgumentsParser process.ArgumentsParser
MinTransactionVersion uint32
HeaderIntegrityVerifier process.HeaderIntegrityVerifier
EnableSignTxWithHashEpoch uint32
TxSignHasher hashing.Hasher
EpochNotifier process.EpochNotifier
}
ArgsEpochStartInterceptorContainer holds the arguments needed for creating a new epoch start interceptors container factory
Click to show internal directories.
Click to hide internal directories.